# -*- coding: utf-8 -*-

from __future__ import unicode_literals

__title__ = "djangocms-restapi"
__version__ = "0.0.1"
__author__ = "Rolf Håvard Blindheim"
__license__ = "MIT License"

VERSION = __version__
